import React from "react";

import { listCommands, listAvatars, getItems, getEntities, getScenes } from "@backend/data";

import "@css/views/PlainText.scss";

class PlainText extends React.PureComponent {
    /**
     * Creates a paragraph of commands.
     * @private
     */
    private getCommands(): React.ReactNode {
        return (
            <>
                {listCommands().map((command) => (
                    <p>{`${command.name[0]} : ${command.description}`}</p>
                ))}
            </>
        );
    }

    /**
     * Creates a paragraph of avatars.
     * @private
     */
    private getAvatars(): React.ReactNode {
        return (
            <>
                {listAvatars()
                    .sort((a, b) => a.id - b.id)
                    .map((avatar) => (
                        <p>{`${avatar.id} : ${avatar.name}`}</p>
                    ))}
            </>
        );
    }

    /**
     * Creates a paragraph of items.
     * @private
     */
    private getItems(): React.ReactNode {
        return (
            <>
                {getItems()
                    .sort((a, b) => a.id - b.id)
                    .map((item) => (
                        <p>{`${item.id} : ${item.name}`}</p>
                    ))}
            </>
        );
    }

    /**
     * Creates a paragraph of monsters.
     * @private
     */
    private getMonsters(): React.ReactNode {
        return (
            <>
                {getEntities()
                    .sort((a, b) => a.id - b.id)
                    .map((entity) => (
                        <p>{`${entity.id} : ${entity.name}`}</p>
                    ))}
            </>
        );
    }

    /**
     * Creates a paragraph of scenes.
     * @private
     */
    private getScenes(): React.ReactNode {
        return (
            <>
                {getScenes()
                    .sort((a, b) => a.id - b.id)
                    .map((scene) => (
                        <p>{`${scene.id} : ${scene.identifier} [${scene.type}]`}</p>
                    ))}
            </>
        );
    }

    render() {
        return (
            <div className={"PlainText"}>
                <p>
                    // Grasscutter 3.6.0 GM Handbook
                    <br />
                    // Generated by the HTML GM Handbook.
                    <br />
                    <br />
                    <br />
                    // Commands
                </p>

                {this.getCommands()}

                <p>
                    <br />
                    <br />
                    // Avatars
                </p>

                {this.getAvatars()}

                <p>
                    <br />
                    <br />
                    // Items
                </p>

                {this.getItems()}

                <p>
                    <br />
                    <br />
                    // Monsters
                </p>

                {this.getMonsters()}

                <p>
                    <br />
                    <br />
                    // Scenes
                </p>

                {this.getScenes()}
            </div>
        );
    }
}

export default PlainText;
